from django.contrib import messages
from django.shortcuts import redirect
from django.urls import resolve

class VerificarPermisosMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        # Evitar bucles: no aplicar lógica al dashboard
        rutas_exentas = ['dashboard', 'login', 'logout']

        if request.user.is_authenticated:
            view_name = resolve(request.path).url_name  # Obtener nombre de la vista
            if view_name in rutas_exentas:
                return self.get_response(request)

            restricciones = {
                'listar_usuarios': 'Administrador',
                'crear_usuario': 'Administrador',
            }

            if view_name in restricciones:
                rol_requerido = restricciones[view_name]
                if not request.user.groups.filter(name=rol_requerido).exists():
                    messages.error(request, "No tienes los permisos necesarios para esta acción.")
                    return redirect('dashboard')

        return self.get_response(request)

