from django.urls import path
from django.contrib.auth import views as auth_views
from . import views

urlpatterns = [
    #Dashboard
    path('', views.dashboard, name='dashboard'),

    # Login y logout
    path('login/', auth_views.LoginView.as_view(template_name='core/login.html'), name='login'),
    path('logout/', auth_views.LogoutView.as_view(), name='logout'),

    #Clientes
    path('clientes/crear/', views.crear_cliente, name='crear_cliente'),
    path('clientes/', views.listar_clientes, name='listar_clientes'),
    path('clientes/<int:cliente_id>/editar/', views.editar_cliente, name='editar_cliente'),
    path('clientes/<int:cliente_id>/eliminar/', views.eliminar_cliente, name='eliminar_cliente'),
    path('clientes/<int:cliente_id>/', views.detalle_cliente, name='detalle_cliente'),
    path('clientes/<int:cliente_id>/crear-transaccion/', views.crear_transaccion, name='crear_transaccion'),
    path('clientes/<int:cliente_id>/editar-transaccion/', views.editar_transaccion, name='editar_transaccion'),
    
    #Vehiculos
    path('vehiculos/', views.listar_vehiculos, name='listar_vehiculos'),
    path('vehiculos/crear/', views.crear_vehiculo, name='crear_vehiculo'),
    path('vehiculos/<int:vehiculo_id>/editar/', views.editar_vehiculo, name='editar_vehiculo'),
    path('vehiculos/<int:vehiculo_id>/eliminar/', views.eliminar_vehiculo, name='eliminar_vehiculo'),

    # Transacciones
    path('transacciones/<int:transaccion_id>/editar/', views.editar_transaccion, name='editar_transaccion'),

    # Cobros
    path('cobros/', views.listar_cobros, name='listar_cobros'),
    path('cobros/crear/', views.crear_cobro, name='crear_cobro'),
    path('cobros/<int:cobro_id>/editar/', views.editar_cobro, name='editar_cobro'),
    path('cobros/<int:cobro_id>/eliminar/', views.eliminar_cobro, name='eliminar_cobro'),
    path('resumen-cobros/', views.resumen_cobros, name='resumen_cobros'),

    # Usuarios
    path('usuarios/crear/', views.crear_usuario, name='crear_usuario'),
    path('usuarios/', views.listar_usuarios, name='listar_usuarios'),
    path('usuarios/<int:usuario_id>/', views.detalle_usuario, name='detalle_usuario'),
    path('usuarios/<int:usuario_id>/editar/', views.editar_usuario, name='editar_usuario'),
    path('usuarios/eliminar/<int:user_id>/', views.eliminar_usuario, name='eliminar_usuario'),

    # Importaciones
    path('importaciones/crear/', views.crear_importacion, name='crear_importacion'),
    path('importaciones/', views.listar_importaciones, name='listar_importaciones'),
    path('importaciones/<int:importacion_id>/editar/', views.editar_importacion, name='editar_importacion'),
    path('importaciones/<int:importacion_id>/eliminar/', views.eliminar_importacion, name='eliminar_importacion'),

    # Despacho
    path('despacho/<int:despacho_id>/vehiculos/', views.lista_vehiculos_por_despacho, name='lista_vehiculos_por_despacho'),

    #Cambio de contraseña
    path('cambiar_contrasena/', views.cambiar_contrasena, name='cambiar_contrasena'),
]
