from functools import wraps
from django.http import JsonResponse
from django.contrib import messages
from django.shortcuts import redirect

def verificar_permisos(permiso_requerido):
    """
    Decorador para verificar si el usuario tiene el permiso necesario.
    Si no tiene permisos, devuelve una respuesta JSON o muestra un mensaje.
    """
    def decorator(view_func):
        @wraps(view_func)
        def _wrapped_view(request, *args, **kwargs):
            if not permiso_requerido(request.user):  # Verifica si el usuario tiene el permiso
                if request.headers.get('x-requested-with') == 'XMLHttpRequest':
                    return JsonResponse({'error': 'No tienes los permisos necesarios para realizar esta acción.'}, status=403)
                else:
                    messages.error(request, "No tienes los permisos necesarios para realizar esta acción.")
                    return redirect('dashboard')  # Redirigir a la página principal
            return view_func(request, *args, **kwargs)
        return _wrapped_view
    return decorator
